const products = [
    {
        id: 1,
        name: "Premium Headphones",
        price: 199.99,
        description: "High-quality wireless headphones with noise cancellation",
        longDescription: "Experience crystal clear audio with our premium wireless headphones featuring advanced noise cancellation technology.",
        thumbnail: "data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 100 100'%3E%3Crect width='100' height='100' fill='%23ddd'/%3E%3C/svg%3E",
        stock: 10
    },
    // Add more products here
];

let cart = [];

document.getElementById('viewProductsBtn').addEventListener('click', showProducts);
document.getElementById('cartBtn').addEventListener('click', showCart);
document.getElementById('placeOrderBtn').addEventListener('click', placeOrder);
document.getElementById('cancelOrderBtn').addEventListener('click', cancelOrder);
document.getElementById('continueShoppingBtn').addEventListener('click', showProducts);

function showProducts() {
    document.querySelector('.landing-hero').style.display = 'none';
    document.getElementById('shoppingCart').style.display = 'none';
    document.getElementById('productDetails').style.display = 'none';
    
    const productsGrid = document.getElementById('productsGrid');
    productsGrid.style.display = 'grid';
    productsGrid.innerHTML = '';
    
    products.forEach(product => {
        const productCard = createProductCard(product);
        productsGrid.appendChild(productCard);
    });
}

function createProductCard(product) {
    const div = document.createElement('div');
    div.className = 'product-card';
    div.innerHTML = `
        <img src="${product.thumbnail}" alt="${product.name}">
        <h3>${product.name}</h3>
        <p>$${product.price}</p>
        <p>${product.description}</p>
        <button onclick="selectProduct(${product.id})">Select</button>
    `;
    return div;
}

function selectProduct(id) {
    const product = products.find(p => p.id === id);
    showProductDetails(product);
}

function showProductDetails(product) {
    document.getElementById('productsGrid').style.display = 'none';
    const details = document.getElementById('productDetails');
    details.style.display = 'block';
    details.innerHTML = `
        <div class="product-details-card">
            <img src="${product.thumbnail}" alt="${product.name}">
            <h2>${product.name}</h2>
            <p>ID: ${product.id}</p>
            <p>$${product.price}</p>
            <p>${product.longDescription}</p>
            <button onclick="addToCart(${product.id})">Add to Cart</button>
            <button onclick="showProducts()">See More Products</button>
        </div>
    `;
}

function addToCart(id) {
    const product = products.find(p => p.id === id);
    const cartItem = cart.find(item => item.id === id);
    
    if (cartItem) {
        cartItem.quantity++;
    } else {
        cart.push({...product, quantity: 1});
    }
    
    alert('Product added to cart!');
    updateCartTotal();
}

function showCart() {
    document.querySelector('.landing-hero').style.display = 'none';
    document.getElementById('productsGrid').style.display = 'none';
    document.getElementById('productDetails').style.display = 'none';
    document.getElementById('shoppingCart').style.display = 'block';
    
    updateCartDisplay();
}

function updateCartDisplay() {
    const cartItems = document.getElementById('cartItems');
    cartItems.innerHTML = '';
    
    cart.forEach(item => {
        const div = document.createElement('div');
        div.className = 'cart-item';
        div.innerHTML = `
            <span>${item.name}</span>
            <input type="number" value="${item.quantity}" min="0" onchange="updateQuantity(${item.id}, this.value)">
            <span>$${(item.price * item.quantity).toFixed(2)}</span>
        `;
        cartItems.appendChild(div);
    });
    
    updateCartTotal();
}

function updateQuantity(id, quantity) {
    const item = cart.find(item => item.id === id);
    item.quantity = parseInt(quantity);
    updateCartTotal();
}

function updateCartTotal() {
    const total = cart.reduce((sum, item) => sum + (item.price * item.quantity), 0);
    document.getElementById('cartTotal').textContent = total.toFixed(2);
}

function placeOrder() {
    if (cart.length === 0) {
        alert('Your cart is empty!');
        return;
    }
    
    const orderNumber = Math.random().toString(36).substr(2, 9);
    alert(`Order placed successfully! Your order number is: ${orderNumber}`);
    cart = [];
    updateCartDisplay();
}

function cancelOrder() {
    cart = [];
    updateCartDisplay();
}